==> teamapps-client-0.9.32.zip: tsd/modules/DefaultTeamAppsUiContext.d.ts <==
import { TeamAppsUiContextInternalApi } from "./TeamAppsUiContext";
import { UiConfigurationConfig } from "../generated/UiConfigurationConfig";
import { UiComponentConfig } from "../generated/UiComponentConfig";
import { UiEvent } from "../generated/UiEvent";
import { UiCommand } from '../generated/UiCommand';
import { TemplateRegistry } from "./TemplateRegistry";
import { TeamAppsEvent } from "./util/TeamAppsEvent";
import { UiComponent } from "./UiComponent";
export declare class DefaultTeamAppsUiContext implements TeamAppsUiContextInternalApi {
    private static logger;
    readonly onStaticMethodCommandInvocation: TeamAppsEvent<UiCommand>;
    readonly sessionId: string;
    isHighDensityScreen: boolean;
    config: UiConfigurationConfig;
    readonly templateRegistry: TemplateRegistry;
    private components;
    private _executingCommand;
    private connection;
    constructor(webSocketUrl: string, clientParameters?: {
        [key: string]: string | number;
    });
    readonly executingCommand: boolean;
    fireEvent(eventObject: UiEvent): void;
    registerComponent(component: UiComponent<UiComponentConfig>, id: string, teamappsType: string): void;
    createAndRegisterComponent(config: UiComponentConfig): UiComponent<UiComponentConfig>;
    destroyComponent(componentId: string): void;
    refreshComponent(config: UiComponentConfig): void;
    getComponentById(id: string): UiComponent<UiComponentConfig>;
    private executeCommands;
    private replaceComponentReferencesWithInstances;
    private commandExecutor;
    private executeCommand;
}

==> teamapps-client-0.9.38.zip: tsd/modules/DefaultTeamAppsUiContext.d.ts <==
import { TeamAppsUiContextInternalApi } from "./TeamAppsUiContext";
import { UiConfigurationConfig } from "../generated/UiConfigurationConfig";
import { UiComponentConfig } from "../generated/UiComponentConfig";
import { UiEvent } from "../generated/UiEvent";
import { UiCommand } from '../generated/UiCommand';
import { TemplateRegistry } from "./TemplateRegistry";
import { TeamAppsEvent } from "./util/TeamAppsEvent";
import { UiClientObject } from "./UiClientObject";
import { UiClientObjectConfig } from "../generated/UiClientObjectConfig";
export declare class DefaultTeamAppsUiContext implements TeamAppsUiContextInternalApi {
    private static logger;
    readonly onStaticMethodCommandInvocation: TeamAppsEvent<UiCommand>;
    readonly sessionId: string;
    isHighDensityScreen: boolean;
    config: UiConfigurationConfig;
    readonly templateRegistry: TemplateRegistry;
    private components;
    private _executingCommand;
    private connection;
    constructor(webSocketUrl: string, clientParameters?: {
        [key: string]: string | number;
    });
    readonly executingCommand: boolean;
    fireEvent(eventObject: UiEvent): void;
    registerClientObject(clientObject: UiClientObject, id: string, teamappsType: string): void;
    createClientObject(config: UiClientObjectConfig): UiClientObject;
    refreshComponent(config: UiComponentConfig): void;
    destroyClientObject(id: string): void;
    getClientObjectById(id: string): UiClientObject;
    private replaceComponentReferencesWithInstances;
    private commandExecutor;
    private executeCommand;
}
